@@ -1,6 +1,4 @@
-// -*- c++ -*-
-/*
- * Copyright 2002, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -17,8 +15,8 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
-#ifndef _SIGC_ADAPTOR_HPP_
-#define _SIGC_ADAPTOR_HPP_
+#ifndef SIGC_ADAPTOR_HPP
+#define SIGC_ADAPTOR_HPP
 
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/adaptors/bind_return.h>
@@ -28,6 +26,5 @@
 #include <sigc++/adaptors/compose.h>
 #include <sigc++/adaptors/exception_catch.h>
 #include <sigc++/adaptors/track_obj.h>
-#include <sigc++/adaptors/lambda/lambda.h>
 
-#endif /* _SIGC_ADAPTOR_HPP_ */
+#endif /* SIGC_ADAPTOR_HPP */
