@@ -20,15 +20,13 @@
 #define SIGC_FUNCTORS_PTR_FUN_H
 #include <sigc++/type_traits.h>
 #include <functional>
+#include <utility>
 
 namespace sigc
 {
 
 /** @defgroup ptr_fun ptr_fun()
- * ptr_fun() creates a functor from a pointer to a function.
- * If the function pointer is to an overloaded type, you must specify
- * the types using template arguments starting with the first argument.
- * It is not necessary to supply the return type.
+ * %ptr_fun() creates a functor from a pointer to a function.
  *
  * @par Example:
  * @code
@@ -36,6 +34,9 @@ namespace sigc
  * sigc::slot<void(int)> sl = sigc::ptr_fun(&foo);
  * @endcode
  *
+ * If the function pointer is to an overloaded type, you must specify
+ * the types using template arguments.
+ *
  * @par Example:
  * @code
  * void foo(int) {}  // choose this one
@@ -44,7 +45,7 @@ namespace sigc
  * sigc::slot<void(long)> sl = sigc::ptr_fun<void, int>(&foo);
  * @endcode
  *
- * ptr_fun() can also be used to convert a pointer to a static member
+ * %ptr_fun() can also be used to convert a pointer to a static member
  * function to a functor, like so:
  *
  * @par Example:
@@ -68,10 +69,10 @@ namespace sigc
  *
  * @ingroup ptr_fun
  */
-template <typename T_return, typename... T_args>
+template<typename T_return, typename... T_args>
 class pointer_functor;
 
-template <typename T_return, typename... T_args>
+template<typename T_return, typename... T_args>
 class pointer_functor<T_return(T_args...)>
 {
   using function_type = T_return (*)(T_args...);
@@ -80,7 +81,6 @@ protected:
   function_type func_ptr_;
 
 public:
-
   /// Constructs an invalid functor.
   pointer_functor() = default;
 
@@ -93,8 +93,9 @@ public:
    * @param a Arguments to be passed on to the function.
    * @return The return value of the function invocation.
    */
-  T_return operator()(type_trait_take_t<T_args>... a) const {
-    return std::invoke(func_ptr_, a...);
+  T_return operator()(type_trait_take_t<T_args>... a) const
+  {
+    return std::invoke(func_ptr_, std::forward<type_trait_take_t<T_args>>(a)...);
   }
 };
 
@@ -104,7 +105,7 @@ public:
  *
  * @ingroup ptr_fun
  */
-template <typename T_return, typename... T_args>
+template<typename T_return, typename... T_args>
 inline decltype(auto) ptr_fun(T_return (*func)(T_args...))
 {
   return pointer_functor<T_return(T_args...)>(func);
